Licencia Ğ1 - v0.2.9
====================

:Date: 2017-04-04 12:59
:Modified: 2022-03-21 19:15

**Licencia de la moneda y compromiso de responsabilidad.**

Cualquier certificación de nueva membresía de Ğ1 debe ir primero acompañada por la transmisión de esta licencia de moneda Ğ1 cuyo certificador debe asegurar que ha sido estudiada, entendida y aceptada por la persona que será certificada.

Cualquier evento de encuentro relacionado con Ğ1 debe ir acompañado de la transmisión de esta licencia, que puede leerse en voz alta y transmitirse por cualquier medio.

Red de confianza Ğ1 (RdC Ğ1)
------------------------------

** Aviso de advertencia :** Certificar no solo es asegurarse de que te has encontrado físicamente con la persona. Es asegurar a la comunidad Ğ1 que conoces a la persona lo suficientemente bien y que sabrás cómo contactarla fácilmente, y ser capaz de identificar una cuenta duplicada o falsa realizada por una persona que has certificado, u otro tipo de problema (desaparición ...), efectuando verificaciones comparativas que revelen el problema.

**Consejos fuertemente recomendados**

Conocer bien a una persona significa que puedes comunicarte con ella por varios medios distintos (físicos, electrónicos, etc ...) pero también que conoces a varias personas que también la conocen bien y, por lo tanto, pueden contactar con ella igualmente. Además si no conoces bien a nadie de quienes ya le han certificado, es una clara indicación de que no conoces bien a la persona; una certificación de este tipo provoca una alerta hacia toda la comunidad Ğ1. En caso de conocimiento insuficiente, es importante NO certificar.

Nunca certifiques solo/a, sino acompáñate por al menos otro/a miembro de la RdC Ğ1 para evitar cualquier error de manejo. En caso de error, advierte a quienes ya son miembros de la RdC Ğ1 inmediatamente.

Antes de cualquier certificación, asegúrate de verificar si su cuenta (tanto si es nueva candidatura o ya miembro) ha recibido ya una o más certificaciones. Si es necesario, solicite información para ponerte en contacto con quienes ya le hayan certificado para verificar juntos/as que conocéis bien la persona en cuestión concerniente, así como su llave pública correspondiente.

Comprueba que la persona a ser certificada domina bien el manejo de su cuenta: una buena manera de comprobar esto es transferir unas Ğ1 a la cuenta destino, y luego pedir la devolución a tu propia cuenta. Esto asegura el buen manejo por quien va a ser certificado, de su llave privada.

Comprueba que tus contactos hayan estudiado y comprendido la licencia Ğ1 actualizada.

Si te percatas de que un/a certificador/a real o potencial de la cuenta candidata no conoce a la persona interesada, avisa inmediatamente a quien tenga experiencia en el tema de tus contactos en la RdC Ğ1, para que la RdC Ğ1 verifique el proceso de validación.

Cuando eres miembro de la RdC Ğ1 y estás a punto de certificar una nueva cuenta:


** Estás seguro de: **

1°) Conocer suficientemente bien (no solamente de vista) a la persona que declara poseer esta llave pública (nueva cuenta). Lea los consejos fuertemente recomendados más arriba para asegurarte de que la "conoces bien".

2°) Haber comprobado personalmente con ella de que se trata de esta llave pública que está a punto de certificar (lea las sugerencias anteriores).

3°) Haber verificado con la persona interesada que ha generado su documento o archivo de revocación de cuenta Duniter que le permitirá, si es necesario, desactivar su estado de miembro (en caso de robo de cuenta, cambio de identificación, cuenta creada incorrectamente, etc.).

4a°) De haberte encontrado con la persona físicamente para asegurarte de que es ella a quien conoces bien y quién posee esta llave pública.

4b°) O realizar de forma remota la verificación entre la llave pública y esa persona (que ya has encontrado físicamente), contactándola por diferentes medios de comunicación, como por correo ordinario + redes sociales + foro + correo electronico + video conferencia + teléfono (reconociendo la voz). Ya que si se puediese piratear una cuenta de correo electrónico o una cuenta en un foro, es mucho más difícil imaginar piratear cuatro medios de comunicación separados, e imitar la apariencia (video) e incluso la voz de la persona.

El 4a°) sin embargo, es preferible al 4b°), mientras que los puntos 1°) 2°) y 3°) son ante todo indispensables.

**Reglas abreviadas de la RdC :**

Cada miembro tiene una reserva de 100 certificaciones posibles, que solo puede emitir a razón de 1 certificación cada 5 días.

Válida durante 2 meses, una certificación se toma en consideración definitivamente para una nueva candidatura de membresía si esta persona tiene al menos otras 4 certificaciones al cabo de estos 2 meses, de lo contrario, el proceso de candidatura deberá reiniciarse.

Para convertirse en nuevo/a miembro de la RdC Ğ1 es necesario obtener 5 certificaciones y estar a una distancia de <= 5 pasos con como mínimo un 80% del total de miembros referentes de la RdC.

Alguien es miembro referente de la RdC Ğ1 cuando ha recibido y también emitido al menos Y[N] certificaciones donde N es el total de miembros en la RdC e Y[N] = techo N^(1/5). Ejemplos:

* Para 1024 < N ≤ 3125 se obtiene que Y[N] = 5
* Para 7776 < N ≤ 16807 se obtiene que Y[N] = 7
* para 59049 < N ≤ 100.000 se obtiene que Y[N] = 10

Una vez que alguien es nuevo/a miembro de la RdC Ğ1, sus certificaciones serán válidas durante 2 años.

Para seguir siendo miembro, se debe renovar el acuerdo regularmente mediante la llave privada (cada 12 meses) y asegurarse de que siempre se tenga al menos 5 certificaciones válidas después de los 2 años.

Moneda Ğ1
----------

Ğ1 se genera a través de un Dividendo Universal (DU) para cada ser humano miembro de la Red de Confianza Ğ1, de la siguiente forma:

* 1 DU por persona y por día.

La cantidad en Ğ1 del DU es idéntica cada día hasta el próximo equinoccio(cada 6 meses) cuando se re-evaluará el DU según la fórmula :

* DU diario (próximo equinoccio) = DU diario (equinoccio) + c² (M/N)(equinoccio) / (15778800 segundos)

Y como parámetros:

* c = 4,88% / equinoccio
* DU(0) = 10,00 Ğ1

Y como variables :

* *M* la masa monetaria total en el equinoccio
* *N* el número de miembros el día del equinoccio

Software Ğ1 y licencia Ğ1
--------------------------

El software Ğ1 que permita a los usuarios administrar su uso de Ğ1 debe transmitir esta licencia y todos los parámetros técnicos de la moneda Ğ1 y de la RdC Ğ1 que han sido configurados en el bloque 0 de Ğ1. El software que no cumpla con estas obligaciones de la licencia no es compatible con Ğ1.

Para más detalle en los aspectos técnicos, es posible consultar directamente el código de Duniter, que es un software libre así como los datos de la cadena de bloques (blockchain) Ğ1, recuperándolos a través de una instancia (o nodo) de Duniter Ğ1.

Más información en el sitio web del equipo Duniter https://www.duniter.org
